@@ -137,7 +137,7 @@ def is_multilabel(y):
     Returns
     -------
     out : bool
-        Return ``True``, if ``y`` is in a multilabel format, else ```False``.
+        Return ``True``, if ``y`` is in a multilabel format, else ``False``.
 
     Examples
     --------
@@ -185,9 +185,8 @@ def is_multilabel(y):
         if y.format in ("dok", "lil"):
             y = y.tocsr()
         labels = xp.unique_values(y.data)
-        return (
-            len(y.data) == 0
-            or (labels.size == 1 or (labels.size == 2) and (0 in labels))
+        return len(y.data) == 0 or (
+            (labels.size == 1 or ((labels.size == 2) and (0 in labels)))
             and (y.dtype.kind in "biu" or _is_integral_float(labels))  # bool, int, uint
         )
     else:
@@ -318,8 +317,7 @@ def type_of_target(y, input_name="", raise_unknown=False):
     valid = (
         (isinstance(y, Sequence) or issparse(y) or hasattr(y, "__array__"))
         and not isinstance(y, str)
-        or is_array_api_compliant
-    )
+    ) or is_array_api_compliant
 
     if not valid:
         raise ValueError(
@@ -360,17 +358,12 @@ def type_of_target(y, input_name="", raise_unknown=False):
                 y = check_array(y, dtype=object, **check_y_kwargs)
 
     try:
-        # TODO(1.7): Change to ValueError when byte labels is deprecated.
-        # labels in bytes format
         first_row_or_val = y[[0], :] if issparse(y) else y[0]
+        # labels in bytes format
         if isinstance(first_row_or_val, bytes):
-            warnings.warn(
-                (
-                    "Support for labels represented as bytes is deprecated in v1.5 and"
-                    " will error in v1.7. Convert the labels to a string or integer"
-                    " format."
-                ),
-                FutureWarning,
+            raise TypeError(
+                "Support for labels represented as bytes is not supported. Convert "
+                "the labels to a string or integer format."
             )
         # The old sequence of sequences format
         if (
@@ -420,7 +413,16 @@ def type_of_target(y, input_name="", raise_unknown=False):
     # Check multiclass
     if issparse(first_row_or_val):
         first_row_or_val = first_row_or_val.data
-    if cached_unique(y).shape[0] > 2 or (y.ndim == 2 and len(first_row_or_val) > 1):
+    classes = cached_unique(y)
+    if y.shape[0] > 20 and classes.shape[0] > round(0.5 * y.shape[0]):
+        # Only raise the warning when we have at least 20 samples.
+        warnings.warn(
+            "The number of unique classes is greater than 50% of the number "
+            "of samples.",
+            UserWarning,
+            stacklevel=2,
+        )
+    if classes.shape[0] > 2 or (y.ndim == 2 and len(first_row_or_val) > 1):
         # [1, 2, 3] or [[1., 2., 3]] or [[1, 2]]
         return "multiclass" + suffix
     else:
